==> Wordpress-3.3.1.tar: wp-config.php <==
<?php
/**
 * Основные параметры WordPress.
 *
 * Этот файл содержит следующие параметры: настройки MySQL, префикс таблиц,
 * секретные ключи, язык WordPress и ABSPATH. Дополнительную информацию можно найти
 * на странице {@link http://codex.wordpress.org/Editing_wp-config.php Editing
 * wp-config.php} Кодекса. Настройки MySQL можно узнать у хостинг-провайдера.
 *
 * Этот файл используется сценарием создания wp-config.php в процессе установки.
 * Необязательно использовать веб-интерфейс, можно скопировать этот файл
 * с именем "wp-config.php" и заполнить значения.
 *
 * @package WordPress
 */

// ** Параметры MySQL: Эту информацию можно получить у вашего хостинг-провайдера ** //
/** Имя базы данных для WordPress */
define('DB_NAME', '[dbname]');

/** Имя пользователя MySQL */
define('DB_USER', '[dbuser]');

/** Пароль к базе данных MySQL */
define('DB_PASSWORD', '[dbpassword]');

/** Имя сервера MySQL */
define('DB_HOST', '[dbhost.port]');

/** Кодировка базы данных для создания таблиц. */
define('DB_CHARSET', 'utf8');

/** Схема сопоставления. Не меняйте, если не уверены. */
define('DB_COLLATE', '');

/**#@+
 * Уникальные ключи и соли для аутентификации.
 *
 * Смените значение каждой константы на уникальную фразу.
 * Можно сгенерировать их с помощью {@link https://api.wordpress.org/secret-key/1.1/salt/ сервиса ключей на WordPress.org}
 * Можно изменить их, чтобы сделать существующие файлы cookies недействительными. Пользователям потребуется снова авторизоваться.
 *
 * @since 2.6.0
 */
define('AUTH_KEY',         'cjOh07!)$Lu9_Y1qTs-KO{S7kqYDO3U}k*fm;tbk:)_KwG#F)Mh1sp2D_hP=6_Yz');
define('SECURE_AUTH_KEY',  '4#mKLE@-MpB2CZ} %wN-MfqPY#V^8i.T&N+lk~E)uPY%^)f`dR>!dW39_A_|l#lF');
define('LOGGED_IN_KEY',    '8FYC#)/#9puIBP{wyhWRdv7A;.o=B![!`7}%B3F~]P4k*?)13P.])i}QZ7m+P;?o');
define('NONCE_KEY',        'iuOY:3G6f1uHzeA5Bd/T`f0?<;au}hMQylrdS|{$=:KLU-9lO `Cma5gfhZ(#B}P');
define('AUTH_SALT',        'sf@Y;2tdG[`nN`-nDPo5gVWaW%}[!(#}7bmJ!~I;l]Ne%ns0#u.%{YwV92A*C[k|');
define('SECURE_AUTH_SALT', 'hZxbqnNUR7&LPMceEU:??v:b6xj,=xh0G/^e5F73k-I4}wgnrFNGJ>=MomZ+ZFjj');
define('LOGGED_IN_SALT',   '$_bAN*8dofOh,qx,{X$G68d(?03H9:@Zs:r1iX%Cn;.I!Ia+85%gQHhGk2`r&SI*');
define('NONCE_SALT',       ' 60s)T]I+C?0:`D3vyTupCA`AQtBun|)_]&B{!34vT79<DAPpe|Jm09[Ee4FxX8G');

/**#@-*/

/**
 * Префикс таблиц в базе данных WordPress.
 *
 * Можно установить несколько блогов в одну базу данных, если вы будете использовать
 * разные префиксы. Пожалуйста, указывайте только цифры, буквы и знак подчеркивания.
 */
$table_prefix  = 'wp_';

/**
 * Язык локализации WordPress, по умолчанию английский.
 *
 * Измените этот параметр, чтобы настроить локализацию. Соответствующий MO-файл
 * для выбранного языка должен быть установлен в wp-content/languages. Например,
 * чтобы включить поддержку русского языка, скопируйте ru_RU.mo в wp-content/languages
 * и присвойте WPLANG значение 'ru_RU'.
 */
define('WPLANG', 'ru_RU');

/**
 * Для разработчиков: Режим отладки WordPress.
 *
 * Измените это значение на true, чтобы включить отображение уведомлений при разработке.
 * Настоятельно рекомендуется, чтобы разработчики плагинов и тем использовали WP_DEBUG
 * в своём рабочем окружении.
 */
define('WP_DEBUG', false);

/* Это всё, дальше не редактируем. Успехов! */

/** Абсолютный путь к директории WordPress. */
if ( !defined('ABSPATH') )
	define('ABSPATH', dirname(__FILE__) . '/');

/** Инициализирует переменные WordPress и подключает файлы. */
require_once(ABSPATH . 'wp-settings.php');

==> Wordpress-3.5.1.tar: wp-config.php <==
<?php
/**
 * Основные параметры WordPress.
 *
 * Этот файл содержит следующие параметры: настройки MySQL, префикс таблиц,
 * секретные ключи, язык WordPress и ABSPATH. Дополнительную информацию можно найти
 * на странице {@link http://codex.wordpress.org/Editing_wp-config.php Editing
 * wp-config.php} Кодекса. Настройки MySQL можно узнать у хостинг-провайдера.
 *
 * Этот файл используется сценарием создания wp-config.php в процессе установки.
 * Необязательно использовать веб-интерфейс, можно скопировать этот файл
 * с именем "wp-config.php" и заполнить значения.
 *
 * @package WordPress
 */

// ** Параметры MySQL: Эту информацию можно получить у вашего хостинг-провайдера ** //
/** Имя базы данных для WordPress */
define('DB_NAME', '[dbname]');

/** Имя пользователя MySQL */
define('DB_USER', '[dbuser]');

/** Пароль к базе данных MySQL */
define('DB_PASSWORD', '[dbpassword]');

/** Имя сервера MySQL */
define('DB_HOST', '[dbhost.port]');

/** Кодировка базы данных для создания таблиц. */
define('DB_CHARSET', 'utf8');

/** Схема сопоставления. Не меняйте, если не уверены. */
define('DB_COLLATE', '');

/**#@+
 * Уникальные ключи и соли для аутентификации.
 *
 * Смените значение каждой константы на уникальную фразу.
 * Можно сгенерировать их с помощью {@link https://api.wordpress.org/secret-key/1.1/salt/ сервиса ключей на WordPress.org}
 * Можно изменить их, чтобы сделать существующие файлы cookies недействительными. Пользователям потребуется снова авторизоваться.
 *
 * @since 2.6.0
 */
define('AUTH_KEY',         'g5!l{G0vJC7Y)}HLkZfN%LdM%BYj[c}ZCpEeM)HIR$=0M1 4/MPv(+-md>$_,7g|');
define('SECURE_AUTH_KEY',  '8OfR]K-4.?o|>ogfigFaAWO`R&R_jIq}U;@LXCA)Va3MH6xdi %e/rmFw/3_6R.M');
define('LOGGED_IN_KEY',    'Mp#EfbTzu!PS@7S])oUQ)ZH[rI$P8QJCKh$7&-ke/xp|Ag`ZpWX5=I)FgNOm0<qP');
define('NONCE_KEY',        'lJYsYUQ4 [A}{Kv@:?~*Lxn6@F3AZfR%4Mmhy:N(t~R/>SQ6<>QJap=([>v6@HWh');
define('AUTH_SALT',        '$sm9/B^H%]dHv36Wxzzyv%(+exB1enOwtWHJvzA,x0n-V5v&uSBPH-D}IW /43zK');
define('SECURE_AUTH_SALT', 'ra-Euh3Jr!6;377X*y%#mpe,wAyozm :pJy~QlJ(gdrNP$h.,stdyVu1QZ|N^c_o');
define('LOGGED_IN_SALT',   '&@4e<Ijb=l`j+jMJ8j+WR[3:7*?&:jj&aq{2GqF5CVHkCBu6o8?AZSXl66>,B6:t');
define('NONCE_SALT',       'ZS=b+-^_yyHN8u`s,@He#gB*Q-LZViT_][DNpP0oG1f3Wp9gNo:vu0M*-D DS57!');

/**#@-*/

/**
 * Префикс таблиц в базе данных WordPress.
 *
 * Можно установить несколько блогов в одну базу данных, если вы будете использовать
 * разные префиксы. Пожалуйста, указывайте только цифры, буквы и знак подчеркивания.
 */
$table_prefix  = 'wp_';

/**
 * Язык локализации WordPress, по умолчанию английский.
 *
 * Измените этот параметр, чтобы настроить локализацию. Соответствующий MO-файл
 * для выбранного языка должен быть установлен в wp-content/languages. Например,
 * чтобы включить поддержку русского языка, скопируйте ru_RU.mo в wp-content/languages
 * и присвойте WPLANG значение 'ru_RU'.
 */
define('WPLANG', 'ru_RU');

/**
 * Для разработчиков: Режим отладки WordPress.
 *
 * Измените это значение на true, чтобы включить отображение уведомлений при разработке.
 * Настоятельно рекомендуется, чтобы разработчики плагинов и тем использовали WP_DEBUG
 * в своём рабочем окружении.
 */
define('WP_DEBUG', false);

/* Это всё, дальше не редактируем. Успехов! */

/** Абсолютный путь к директории WordPress. */
if ( !defined('ABSPATH') )
	define('ABSPATH', dirname(__FILE__) . '/');

/** Инициализирует переменные WordPress и подключает файлы. */
require_once(ABSPATH . 'wp-settings.php');
